import React, { Component } from 'react';
import Taro from '@tarojs/taro';
import { View, Picker, ScrollView, Button } from '@tarojs/components'
import { getProjectList, listRecord } from '../../utils/servers/servers';
import dayjs from 'dayjs';
import {
  AtSearchBar,
  AtTabs,
  AtTabsPane,
  AtIcon,
  AtModal,
  AtModalContent,
  AtModalAction,
  AtTextarea
} from 'taro-ui';
import { clockState } from '../../utils/tools/config';

import './index.less';
import 'taro-ui/dist/style/components/tabs.scss';
import "taro-ui/dist/style/components/flex.scss";
import "taro-ui/dist/style/components/action-sheet.scss";
import "taro-ui/dist/style/components/icon.scss";
import "taro-ui/dist/style/components/list.scss";
import "taro-ui/dist/style/components/icon.scss";
import "taro-ui/dist/style/components/modal.scss";

import MyList from './myList';
import InquiryModal from "../../components/common/inquiryModal";
import { resourceAddress } from "../../utils/config";

class Examine extends Component {

  constructor(props) {
    super(props);
    this.state = {
      typeList: [
        { title: '全部', type: 0 },
        { title: '未审核', type: 2 },
        { title: '已审核', type: 1 },],
      current: 0,
      list: [],
      pageNum: 1,
      listState: 'LOADING',

    }
    this.getPublicReleaseList = this.getPublicReleaseList.bind(this);
    this.getMyList = this.getMyList.bind(this);
  }

  componentDidShow() {
    this.getPublicReleaseList();
  }

  async componentDidMount() {
    await this.getPublicReleaseList();
  }

  onPullDownRefresh() {
    this.getPublicReleaseList();
  }

  onReachBottom() {
    this.getPublicReleaseList(true);
  }

  onTabItemTap(obj) {
    if (obj.index === 1) {
      this.onTabTap();
    }
  }

  async onTabTap() {
    await this.getMyList(1);
  }

  async getPublicReleaseList(lv) {
    await this.getMyList(lv ? this.state.pageNum + 1 : 1);
    Taro.stopPullDownRefresh();
  }

  async getMyList(pageNum) {
    const { current } = this.state
    this.setState({
      listState: 'LOADING'
    })
    let data = {
      processStatus: this.state.current != 0 ? this.state.current : "",
      pageNum: pageNum,
      pageSize: 10,
      roleType: 1,
    }
    for (let i in data) {
      if (!data[i] && data[i] != 0) {
        delete data[i]
      }
    }
    let msg = await listRecord(data);
    if (msg.code === 200) {
      if (msg.total === 0) {
        this.setState({
          listState: 'NO_DATA'
        })
      } else if (msg.total === this.state.list.length && pageNum !== 1) {
        !this.state.isOpen && Taro.showToast({ title: '没有更多数据了', icon: 'none' });
        this.setState({
          listState: 'NO_MORE_DATA'
        })
      } else {
        if (msg.total === (pageNum === 1 ? msg.rows : this.state.list.concat(msg.rows)).length) {
          this.setState({
            listState: 'NO_MORE_DATA'
          })
        }
      }
      this.setState({
        list: pageNum === 1 ? msg.rows : this.state.list.concat(msg.rows),
        pageNum: msg.rows.length === 0 ? this.state.pageNum : msg.next - 1
      })
    } else {
      Taro.showToast({ title: msg.msg, icon: 'none' });
      this.setState({
        // listState: msg.error[0].field === '403' ? 'NO_DATA' : 'RELOAD'
      })
    }
    Taro.stopPullDownRefresh();
  }


  render() {
    return (
      <View className='indexPage' >
        <View className='searchContent'>
          <View className='searchTop'>
            {/* <AtSearchBar
              showActionButton
              placeholder='请输入企业/渠道'
              value={this.state.searchValue}
              onActionClick={() => {
                this.getPublicReleaseList();
              }}
              onChange={(value) => {
                this.setState({
                  searchValue: value
                })
              }}
              onClear={() => {
                this.setState({
                  searchValue: ''
                })
              }}
            /> */}
          </View>
        </View>
        <AtTabs
          swipeable={false}
          current={this.state.current || 0}
          tabList={this.state.typeList}
          onClick={(current) => {
            this.setState({
              list: [],
              pageNum: 1,
              current,
            }, () => {
              this.getPublicReleaseList();
            })
          }}>
          {
            this.state.typeList?.map((item, index) =>
              <AtTabsPane
                current={this.state.current}
                index={index}
              >
                <MyList
                  title={item.title}
                  typelist={this.state.typeList}
                  seeView={this.state.current}
                  list={this.state.list}
                  listState={this.state.listState}
                  onRefresh={() => {
                    this.getProjectList(true);
                  }}
                />
              </AtTabsPane>
            )
          }
        </AtTabs>
      </View>
    )
  }
}

export default Examine
